C:::::      ,,,,,LL3FEL....
C
C
C
C**********************************************************************
C        1         2         3         4         5         6         7*
C**********************************************************************
C**                                                                 ***
C**                                                                 ***
      subroutine LL3FEL(lmat,lprec,liprec,lindex,l,ldw,liw,nproc,
     &                  lsym,ia1,info,mat,prec,x,b,dw,iprec,index,
     &                  iw,ilin,lmatbk,ptrmbk,ptrinf,jump,tid,myproc,
     &                  iconv,ierr)
C**                                                                 ***
C**                                                                 ***
C**********************************************************************
C**                                                                 ***
C**      L L 3 F E L   performs the Forward ELimination             ***
C**                                                                 ***
C**********************************************************************
C**                                                                 ***
C**     COPYRIGHT UNIVERSITAET KARLSRUHE RECHENZENTRUM  1996        ***
C**     PROGRAMMER: H. Haefner                                      ***
C**                                                                 ***
C**********************************************************************
C**                                                                 ***
C**     THE IMPLICIT NONE-INSTRUCTION HAS THE AIM,                  ***
C**     THAT ALL VARIABLES MUST BE DECLARED EXPLICITLY.             ***
C**                                                                 ***
      implicit none
C**                                                                 ***
C**-----------------------------------------------------------------***
C**                                                                 ***
C**      FORMAL PARAMETERS :                                        ***
C**      -----------------                                          ***
C**                                                                 ***
      include           'const.h'
      integer           lmat,lprec,liprec,lindex,l,ldw,liw,ia1,iconv,
     #                  ierr,nproc,myproc
      double precision  mat(lmat),prec(lprec),x(l),b(l),dw(ldw)
      integer           index(lindex),info(ia1,ia2),iprec(liprec),
     #                  iw(liw),ilin(nilin),lmatbk(nproc),
     #                  ptrinf(ntyp+1,nproc),
     #                  ptrmbk(nproc+1),jump(nproc),tid(nproc)
      logical           lsym
C**                                                                 ***
C**-----------------------------------------------------------------***
C**                                                                 ***
C**   LIST OF FORMAL PARAMETERS :                                   ***
C**   -------------------------                                     ***
C**   (see also Manual-Pages <linsol>)                              ***
C**                                                                 ***
C**                                                                 ***
C--------I------I------I-----------------------------------------------
C  NAME  I TYPE I  I/O I     MEANING
C--------I------I------I-----------------------------------------------
C  prec  I  DP  I  I/O I   contains normalization vector, original  
C        I      I      I   initial guess, original right hand side (rhs), 
C        I      I      I   original rhs multiplied by normalization 
C        I      I      I   vector and Pl (left Preconditioning matrix),
C        I      I      I   rhs multiplied by normalization vector,
C        I      I      I   Pl (left Preconditioning matrix) and
C        I      I      I   Pr (right Preconditioning matrix)
C        I      I      I   prec(1..l)      : normalization vector (N)
C        I      I      I   prec(l+1..2*l)  : original initial guess (xorg)
C        I      I      I   prec(2*l+1..3*l): original rhs (borg)
C        I      I      I   prec(3*l+1..4*l): Pl*N*borg
C        I      I      I   prec(4*l+1..5*l): N*b
C        I      I      I   prec(iprec(7)+1..iprec(8)): Pl
C        I      I      I   prec(iprec(8)+1..iprec(8)+iprec(4)): Pr
C--------I------I------I-----------------------------------------------
C iprec  I  I   I  OUT I   contains 
C        I      I      I   iprec(1) : length of (local) left
C        I      I      I              Preconditioning matrix (lmatPl)
C        I      I      I   iprec(2) : length of (local) left
C        I      I      I              matrix indices (lindexPl)
C        I      I      I   iprec(3) : first dimension of left matrix
C        I      I      I              information array (ia1Pl)
C        I      I      I   iprec(4) : length of (local) right
C        I      I      I              Preconditioning matrix (lmatPr)
C        I      I      I   iprec(5) : length of (local) right
C        I      I      I              matrix indices (lindexPr)
C        I      I      I   iprec(6) : first dimension of right matrix
C        I      I      I              information array (ia1Pr)
C        I      I      I   iprec(7) : pointer to Pl -1 within
C        I      I      I              array prec
C        I      I      I   iprec(8) : pointer to Pr -1 within
C        I      I      I              array prec
C        I      I      I   iprec(9) : pointer to ixPl -1 within
C        I      I      I              array iprec
C        I      I      I   iprec(10): pointer to infoPl -1 within
C        I      I      I              array iprec
C        I      I      I   iprec(11): pointer to ptrinfPl -1 within
C        I      I      I              array iprec
C        I      I      I   iprec(12): pointer to ixPr -1 within
C        I      I      I              array iprec
C        I      I      I   iprec(13): pointer to infoPr -1 within
C        I      I      I              array iprec
C        I      I      I   iprec(14): pointer to ptrinfPr -1 within
C        I      I      I              array iprec
C        I      I      I   iprec(15): pointer to permutation vector of x -1
C        I      I      I   iprec(iprec(9)+1...iprec(10)):
C        I      I      I              array of left Preconditioning
C        I      I      I              matrix indices ixPl 
C        I      I      I   iprec(iprec(10)+1...iprec(11)):
C        I      I      I              left Preconditioning
C        I      I      I              matrix information array infoPl 
C        I      I      I   iprec(iprec(11)+1...iprec(12)):
C        I      I      I              pointer array ptrinfPl
C        I      I      I   iprec(iprec(12)+1...iprec(13)):
C        I      I      I              array of right Preconditioning
C        I      I      I              matrix indices ixPr 
C        I      I      I   iprec(iprec(13)+1...iprec(14)):
C        I      I      I              right Preconditioning
C        I      I      I              matrix information array infoPr 
C        I      I      I   iprec(iprec(14)+1...iprec(15)):
C        I      I      I              pointer array ptrinfPr
C--------I------I------I-----------------------------------------------
C
C     ilin(8) = 0           NO Preconditioning
C               1,4,..,28   matrix Pl is computed by an iterative
C                           procedure
C               2,5,..,29   matrix Pr is computed by an iterative
C                           procedure
C               3,6,..,30   matrices Pl and Pr are computed by an
C                           iterative procedure
C               1,2,..,30  THERE IS NOTHING TO DO IN THIS PROCEDURE
C
C               31,34,..,58 matrix Pl is computed from the matrix MAT;
C                           preconditioning by multiplication (Pl*MAT)
C               32,35,..,59 matrix Pr is computed from the matrix MAT;
C                           preconditioning by multiplication (MAT*Pr)
C               33,36,..,60 matrices Pl and Pr are computed from the
C                           matrix MAT; preconditioning by multiplication
C                           (Pl*MAT*Pr)
C               31,...,60  THERE IS NOTHING TO DO IN THIS PROCEDURE
C 
C               61,64,..,88 matrix Pl is computed from the matrix MAT;
C                           preconditioning by "forward elimination" and
C                           "backward substitution"
C               62,65,..,89 matrix Pr is computed from the matrix MAT;
C                           preconditioning by "forward elimination" and
C                           "backward substitution"
C               63,66,..,90 matrices Pl and Pr are computed from the
C                           matrix MAT;
C                           preconditioning by "forward elimination" and
C                           "backward substitution"
C               61,...,90  FOR THIS PARAMETER VALUES WORK HAS TO BE DONE
C
C               91          matrix Pl is handed over by the user
C               92          matrix Pr is handed over by the user
C               93          matrices Pl and Pr are handed over by the user
C               91,92,93   THERE IS NOTHING TO DO IN THIS PROCEDURE
C
C**                                                                 ***
C**                                                                 ***
C**      LOCAL PARAMETERS :                                         ***
C**      -----------------                                          ***
C**                                                                 ***
      integer            i,j
C
C
C**** START OF CALCULATION :
C     ---------------------
C

C
C**** END OF CALCULATION
C     ------------------
C
      r e t u r n
C-----END OF LL3FEL----------------------------------------------------
      e    n    d
