C:::::      ,,,,,VEM592...
C**                                                                 ***
C**                                                                 ***
C**                                                                 ***
C**********************************************************************
C**      1         2         3         4         5         6         7*
C**********************************************************************
C**                                                                 ***
C**                                                                 ***
      SUBROUTINE VEM592(DFDUT,DU,EPS,SYM,DIAM,
     &                  T,GROUP,U1,NK,NE,GEOTYP,GEO1,GEONEK,
     &                  NRSP,RSPARM,NRVP,RVP1,RVPARM,
     &                  NISP,ISPARM,NIVP,IVP1,IVPARM,
     &                  NOP1,NOP,NOPARM,NN,NOD,U,UT,MASKL,USERL,
     &                  MASKF,USERF,S,DSDV,ELM1,X,UU,ELM1T,UUT,ENOP,
     &                  TAU,DUDX,DUTDX,DNOPDX,
     &                  NVRB2,VRB2,VRBIG,LIST,OUTCNT,LOUT,ERR)
C**                                                                 ***
C**                                                                 ***
C**********************************************************************
C**                                                                 ***
C**      VEM592     prepares the check of the Frechets on           ***
C**                 area element (CLASS=2,DIM=3).                   ***
C**                 ELM1T>=ELM1 marks the nonsteady case.           ***
C**                                                                 ***
C**                 derivative means derivective with respect of    ***
C**                 TAU.                                            ***
C**                                                                 ***
C**********************************************************************
C**                                                                 ***
C**        Copyrights University of Karlsruhe, 1995                 ***
C**        Program by L. Grosz                                      ***
C**                                                                 ***
C**********************************************************************
C**                                                                 ***
      IMPLICIT NONE
C**                                                                 ***
C**-----------------------------------------------------------------***
C**                                                                 ***
C**      Formal Parameters :                                        ***
C**      -----------------                                          ***
C**                                                                 ***
C**                    >                                            ***
      INTEGER           GROUP,U1,NK,GEOTYP,NE,GEO1,NRSP,NRVP,RVP1,
     &                  NISP,NIVP,IVP1,NN,ELM1,NVRB2,
     &                  VRB2,NOP1,NOP,ELM1T,OUTCNT,LOUT,ERR

      INTEGER           GEONEK(GEO1,GEOTYP),ISPARM(NISP),
     &                  IVPARM(IVP1,NIVP),LIST(NE)

      DOUBLE PRECISION  T,RSPARM(NRSP),RVPARM(RVP1,NRVP),
     &                  NOD(NN,3),U(U1,NK),UT(U1,NK),NOPARM(NOP1,NOP),
     &                  S(GEOTYP),DSDV(GEOTYP,2),
     &                  X(ELM1,3),UU(ELM1,NK),UUT(ELM1T,NK),
     &                  TAU(ELM1,3,2),DUDX(ELM1,NK,2),
     &                  DUTDX(ELM1T,NK,2),
     &                  ENOP(ELM1,NOP),DNOPDX(ELM1,NOP,2),
     &                  VRBIG(ELM1,VRB2),DIAM,EPS,DU

      LOGICAL           MASKL(NK,NK),MASKF(NK),SYM,DFDUT

      EXTERNAL          USERF,USERL
C**                                                                 ***
C**-----------------------------------------------------------------***
C**                                                                 ***
C**   List of Formal Parameters :                                   ***
C**   -------------------------                                     ***
C**                                                                 ***
C--------I------I-----I------------------------------------------------
C Name   I Type I i/o I Meaning
C--------I------I-----I------------------------------------------------
C--------I------I-----I------------------------------------------------
C DFDUT  I  L   I in  I perturbation in direction UT
C--------I------I-----I-----------------------------------------------
C DU     I  R   I in  I increment for U and DUDX
C        I      I     I =0 => no check
C--------I------I-----I-----------------------------------------------
C EPS    I  R   I in  I small positiv machine constant
C--------I------I-----I-----------------------------------------------
C SYM    I  L   I i/o I symmetrical case
C--------I------I-----I-----------------------------------------------
C DIAM   I  R   I in  I diameter of the mesh
C--------I------I-----I-----------------------------------------------
C T      I  R   I in  I current time
C--------I------I-----I-----------------------------------------------
C GROUP  I  I   I in  I current group
C--------I------I-----I-----------------------------------------------
C NK     I  I   I in  I number of components
C--------I------I-----I------------------------------------------------
C NE     I  I   I in  I number of elements
C--------I------I-----I------------------------------------------------
C GEOTYP I  I   I in  I order of shape function
C--------I------I-----I------------------------------------------------
C GEONEK I  I   I in  I mesh array           array: GEONEK(GEO1,GEOTYP)
C--------I------I-----I------------------------------------------------
C NRSP   I  I   I in  I number of real scalar parameters
C--------I------I-----I------------------------------------------------
C RSPARM I  R   I in  I set of real scalar Parameters
C        I      I     I                             array: RVPARM(NRSP)
C--------I------I-----I------------------------------------------------
C NRVP   I  I   I in  I number of real vector parameters
C--------I------I-----I------------------------------------------------
C RVPARM I  R   I in  I set of real vector parameters
C        I      I     I                        array: RVPARM(RVP1,NRVP)
C--------I------I-----I------------------------------------------------
C NISP   I  I   I in  I number of integer scalar parameters
C--------I------I-----I------------------------------------------------
C ISPARM I  R   I in  I set of integer scalar parameters
C        I      I     I                             array: ISPARM(NISP)
C--------I------I-----I------------------------------------------------
C NIVP   I  I   I in  I number of integer vector parameters
C--------I------I-----I------------------------------------------------
C IVPARM I  R   I in  I set of integer vector parameters :
C        I      I     I                         array: IPARM(IVP1,NIVP)
C--------I------I-----I------------------------------------------------
C NOP    I  I   I in  I number of node parameters
C--------I------I-----I------------------------------------------------
C NOPARM I  I   I in  I node parameters         array: NOPARM(NOP1,NOP)
C--------I------I-----I------------------------------------------------
C NOD    I  R   I in  I node coordinates               array: NOD(NN,3)
C--------I------I-----I------------------------------------------------
C U      I  R   I in  I solution at nodes               array: U(U1,NK)
C--------I------I-----I------------------------------------------------
C UT     I  R   I in  I derivative of solution with respect to t
C        I      I     I at nodes                       array: UT(U1,NK)
C--------I------I-----I------------------------------------------------
C MASKF  I  L   I in  I mask of linear form            array: MASKF(NK)
C--------I------I-----I------------------------------------------------
C USERF  I EX   I in  I routine defining linear form
C--------I------I-----I------------------------------------------------
C MASKL  I  L   I in  I mask of frechets            array: MASKL(NK,NK)
C--------I------I-----I------------------------------------------------
C USERL  I EX   I in  I routine defining the frechet
C--------I------I-----I------------------------------------------------
C S      I  R   I in  I shape functions at centre point
C        I      I     I                                array: S(GEOTYP)
C--------I------I-----I------------------------------------------------
C DSDV   I  R   I in  I derivative of shape functions at centre point
C        I      I     I                           array: DSDV(GEOTYP,2)
C--------I------I-----I------------------------------------------------
C X      I  R   I out I centre points of elements      array: X(ELM1,3)
C--------I------I-----I------------------------------------------------
C UU     I  R   I out I solution at centre points    array: UU(ELM1,NK)
C--------I------I-----I------------------------------------------------
C UUT    I  R   I out I derivative of the solution with respect of
C        I      I     I T at the centre points     array: UUT(ELM1T,NK)
C--------I------I-----I------------------------------------------------
C ENOP   I  R   I out I node parameters at centre points
C        I      I     I                           array: ENOP(ELM1,NOP)
C--------I------I-----I------------------------------------------------
C TAU    I  R   I out I directions in the tangential hyperspace
C        I      I     I                            array: TAU(ELM1,3,2)
C--------I------I-----I------------------------------------------------
C DUDX   I  R   I out I derivative of solution at centre points
C        I      I     I                          array: DUDX(ELM1,NK,2)
C--------I------I-----I------------------------------------------------
C DUTDX  I  R   I out I derivative of derivative of the solution with
C        I      I     I respect to t at centre points
C        I      I     I                        array: DUTDX(ELM1T,NK,2)
C--------I------I-----I------------------------------------------------
C DNOPDX I  R   I out I derivative of the node parameters at centre
C        I      I     I point                array: DNOPDX(ELM1T,NOP,2)
C--------I------I-----I------------------------------------------------
C NVRB2  I  I   I out I needed second dimension of VRBIG
C--------I------I-----I------------------------------------------------
C VRBIG  I  R   I -   I vector work array       array: VRBIG(ELM1,VRB2)
C--------I------I-----I------------------------------------------------
C LIST   I  I   I -   I list of failed elements         array: LIST(NE)
C--------I------I-----I------------------------------------------------
C LOUT   I  I   I in  I unit of line out
C--------I------I-----I------------------------------------------------
C OUTCNT I  I   I in  I the first outcnt failed elements are printed
C--------I------I-----I------------------------------------------------
C ERR    I  I   I out I error number   =5920 => small storage
C        I      I     I                =5921 => illegal jacobean
C        I      I     I                =5922 => incorrect frechets
C        I      I     I                =5923 => incorrect mask
C--------I------I-----I------------------------------------------------
C**                                                                 ***
C**                    >                                            ***
      INTEGER           Z,J,LAST,CLASS,IERR,OUT2,NFAIL,DIM
      INTEGER           NORM1,NORM2,DA,
     &                  L3,L2,L1,L0,F1,F0,
     &                  L3H,L2H,L1H,L0H,F1H,F0H,DUDX2
C**                                                                 ***
C**-----------------------------------------------------------------***
C**                                                                 ***
C**** Start of Calculation :                                        ***
C**   ---------------------                                         ***
C**                                                                 ***
      LAST=0
      OUT2=MIN(OUTCNT,NE)
      CLASS=2
      DIM=3
      ERR=0
      NVRB2=0

      NORM1=1
      NORM2=NORM1+1
      DA   =NORM2+1
      NVRB2=MAX(DA+1,NVRB2)

      IF (NVRB2.LE.VRB2) THEN
C**                                                                 ***
C**-----------------------------------------------------------------***
C**                                                                 ***
C****** compute the transformation and its derivatives :            ***
C**     ----------------------------------------------              ***
C**                                                                 ***
        CALL VEM903(NE,LAST+1,DIM,NN,NOD,GEO1,GEOTYP,GEONEK,ELM1,
     &              S(1),DSDV(1,1),DSDV(1,2),
     &              X,TAU(1,1,1),TAU(1,1,2))
C**                                                                 ***
C**-----------------------------------------------------------------***
C**                                                                 ***
C****** compute DA :                                                ***
C**     ----------                                                  ***
C**                                                                 ***
        CALL VEM917(NE,ELM1,TAU(1,1,1),TAU(1,1,2),VRBIG(1,DA))
C**                                                                 ***
C**-----------------------------------------------------------------***
C**                                                                 ***
C****** check element area:                                         ***
C**     ------------------                                          ***
C**                                                                 ***
        NFAIL=0
        DO 100 Z=1,NE
          IF ( VRBIG(Z,DA) .LT. 100 * EPS * DIAM**CLASS ) THEN
            NFAIL=NFAIL+1
            LIST(NFAIL)=Z
          ENDIF
 100    CONTINUE

        IF (NFAIL.GT.0) THEN
          ERR=5921
          WRITE(LOUT,9070) NFAIL,NFAIL,GROUP
          WRITE(LOUT,9080) (LIST(Z),VRBIG(LIST(Z),DA),
     &                                         Z=1,MIN(NFAIL,OUT2))
          GOTO 9999
        ENDIF
C**                                                                 ***
C**-----------------------------------------------------------------***
C**                                                                 ***
C****** normalize TAU and compute DA :                              ***
C**     ----------------------------                                ***
C**                                                                 ***
        CALL VEM915(NE,ELM1,TAU(1,1,1),VRBIG(1,NORM1),
     &                     TAU(1,1,2),VRBIG(1,NORM2),VRBIG(1,DA))
C**                                                                 ***
C**-----------------------------------------------------------------***
C**                                                                 ***
C****** compute the solution and its derivatives on reference       ***
C**     element :                                                   ***
C**     -----------------------------------------------------       ***
C**                                                                 ***
        CALL VEM903(NE,LAST+1,NK,U1,U,GEO1,GEOTYP,GEONEK,ELM1,
     &              S(1),DSDV(1,1),DSDV(1,2),
     &              UU,DUDX(1,1,1),DUDX(1,1,2))

        DO 201 J=1,NK
          DO 201 Z=1,NE
            DUDX(Z,J,1)=VRBIG(Z,NORM1)*DUDX(Z,J,1)
            DUDX(Z,J,2)=VRBIG(Z,NORM2)*DUDX(Z,J,2)
 201    CONTINUE
C**                                                                 ***
C**                                                                 ***
C**-----------------------------------------------------------------***
C**                                                                 ***
C****** compute the T-solution and                                  ***
C**                        its derivatives on reference element :   ***
C**     -------------------------------------------------------     ***
C**                                                                 ***
        IF (ELM1T.GE.ELM1) THEN
          CALL VEM903(NE,LAST+1,NK,U1,UT,GEO1,GEOTYP,GEONEK,ELM1,
     &                S(1),DSDV(1,1),DSDV(1,2),
     &                UUT,DUTDX(1,1,1),DUTDX(1,1,2))

          DO 301 J=1,NK
            DO 301 Z=1,NE
              DUTDX(Z,J,1)=VRBIG(Z,NORM1)*DUTDX(Z,J,1)
              DUTDX(Z,J,2)=VRBIG(Z,NORM2)*DUTDX(Z,J,2)
 301      CONTINUE
        ENDIF
C**                                                                 ***
C**-----------------------------------------------------------------***
C**                                                                 ***
C****** compute the node parameters and                             ***
C**                       their derivatives on reference element :  *** 
C**     --------------------------------------------------------    ***
C**                                                                 ***
        IF (NOP.GT.0) THEN
          CALL VEM903(NE,LAST+1,NOP,NOP1,NOPARM,GEO1,GEOTYP,GEONEK,ELM1,
     &                S(1),DSDV(1,1),DSDV(1,2),
     &                ENOP,DNOPDX(1,1,1),DNOPDX(1,1,2))
          DO 401 J=1,NOP
            DO 401 Z=1,NE
              DNOPDX(Z,J,1)=VRBIG(Z,NORM1)*DNOPDX(Z,J,1)
              DNOPDX(Z,J,2)=VRBIG(Z,NORM2)*DNOPDX(Z,J,2)
 401      CONTINUE
        ENDIF
      ELSE
        ERR=5920
      ENDIF
C**                                                                 ***
C**-----------------------------------------------------------------***
C**                                                                 ***
C**** check frechets :                                              ***
C**   --------------                                                ***
C**                                                                 ***
      L3=1
      L2=L3+CLASS*CLASS
      L1=L2+CLASS
      L0=L1+CLASS
      F1=L0+1
      F0=F1+CLASS
      L3H=F0+1
      L2H=L3H+CLASS*CLASS
      L1H=L2H+CLASS
      L0H=L1H+CLASS
      F1H=L0H+1
      F0H=F1H+CLASS
      DUDX2=F0H+1
      NVRB2=MAX(DUDX2+CLASS*NK,NVRB2)

      IF (NVRB2.LE.VRB2) THEN
        CALL VEM598(DFDUT,DU,EPS,
     &              SYM,T,GROUP,CLASS,NK,NE,
     &              NRSP,RSPARM,NRVP,RVP1,RVPARM,
     &              NISP,ISPARM,NIVP,IVP1,IVPARM,
     &              MASKF,USERF,MASKL,USERL,ELM1,
     &              DIM,X,UU,ELM1T,UUT,NOP,ENOP,
     &              TAU,DUDX,DUTDX,DNOPDX,
     &              LIST,VRBIG(1,F1),VRBIG(1,F0),VRBIG(1,L3),
     &              VRBIG(1,L2),VRBIG(1,L1),VRBIG(1,L0),
     &              VRBIG(1,F1H),VRBIG(1,F0H),VRBIG(1,L3H),
     &              VRBIG(1,L2H),VRBIG(1,L1H),VRBIG(1,L0H),
     &              VRBIG(1,DUDX2),OUTCNT,LOUT,IERR)
        IF (IERR.EQ.5980) THEN
          ERR=5923
          GOTO 9999
        ENDIF
        IF (IERR.EQ.5981) THEN
          ERR=5922
          GOTO 9999
        ENDIF
      ELSE
        ERR=5920
      ENDIF
C**                                                                 ***
C**-----------------------------------------------------------------***
C**                                                                 ***
C**** Formats:                                                      ***
C**   -------                                                       ***
C**                                                                 ***
9070  FORMAT('>>VEMCD:31:0002:',I9
     &      /'>>group ',I3,': ',I9,' illegal element areas.')
9080  FORMAT('>>element ',I9,': element area :',G12.4)
C**                                                                 ***
C**-----------------------------------------------------------------***
C**                                                                 ***
C**** End of Calculation                                            ***
C**   ------------------                                            ***
C**                                                                 ***
9999  CONTINUE
      R E T U R N
C-----End of VEM592----------------------------------------------------
      E    N    D
